import { aws_elasticloadbalancingv2 as elbv2 } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Properties for allocating a priority to an application listener rule.
 */
export interface AllocatePriorityProps {
    /**
     * The listener to allocate the priority to.
     */
    readonly listener: elbv2.IApplicationListener;
    /**
     * The priority to allocate.
     * @default a priority will be allocated automatically.
     */
    readonly priority?: number;
}
/**
 * Properties for the ApplicationListenerPriorityAllocator construct.
 */
export interface ApplicationListenerPriorityAllocatorProps {
    /**
     * The initial priority value to start from.
     * @default 1
     */
    readonly priorityInitialValue?: number;
}
/**
 * This custom resource allows to generate unique priorities for application listener rules.
 *
 * Consumers can allocate a priority to a listener rule by calling the `allocatePriority` method, ensuring that:
 * - if no priority is set, one will be generated
 * - if a priority is set, an error will be thrown if the priority is already taken
 */
export declare class ApplicationListenerPriorityAllocator extends Construct {
    /**
     * Returns the singleton instance of the ApplicationListenerPriorityAllocator for the stack.
     * @param scope The scope of the construct.
     * @returns The singleton instance of the ApplicationListenerPriorityAllocator for the stack.
     */
    static of(scope: Construct): ApplicationListenerPriorityAllocator;
    /**
     * The service token to use to reference the custom resource.
     */
    readonly serviceToken: string;
    constructor(scope: Construct, id: string, props?: ApplicationListenerPriorityAllocatorProps);
    /**
     * Allocates a priority to an application listener rule.
     * @param scope The scope of the construct.
     * @param id The ID of the listener rule to allocate the priority to.
     * @param props
     * @returns The allocated priority.
     */
    allocatePriority(scope: Construct, id: string, props: AllocatePriorityProps): number;
}
